@@ -121,16 +121,22 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
         self.scratches.setState(scratch, "configured")
         animation_type: str = scratch.conf.get("animation", "fromTop").lower()
         defined_class: str = scratch.conf.get("class", "")
+        skipped_windowrules = scratch.conf.get("skip_windowrules", [])
         if defined_class:
             monitor = await self.get_focused_monitor_props(
                 name=scratch.conf.get("force_monitor")
             )
             width, height = convert_coords(scratch.conf.get("size", "80% 80%"), monitor)
 
-            ipc_commands = [
-                f"windowrule float,^({defined_class})$",
-                f"windowrule workspace special:scratch_{scratch.uid} silent,^({defined_class})$",
-            ]
+            ipc_commands = []
+
+            if "float" not in skipped_windowrules:
+                ipc_commands.append(f"windowrule float,^({defined_class})$")
+            if "workspace" not in skipped_windowrules:
+                ipc_commands.append(
+                    f"windowrule workspace special:scratch_{scratch.uid} silent,^({defined_class})$"
+                )
+            set_aspect = "aspect" not in skipped_windowrules
 
             if animation_type:
                 margin_x = (monitor["width"] - width) // 2
@@ -145,9 +151,13 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
                     "fromright": f"200% {margin_y}",
                     "fromleft": f"-200% {margin_y}",
                 }[animation_type]
-                ipc_commands.append(f"windowrule move {t_pos},^({defined_class})$")
+                if set_aspect:
+                    ipc_commands.append(f"windowrule move {t_pos},^({defined_class})$")
 
-            ipc_commands.append(f"windowrule size {width} {height},^({defined_class})$")
+            if set_aspect:
+                ipc_commands.append(
+                    f"windowrule size {width} {height},^({defined_class})$"
+                )
 
             await self.hyprctl(ipc_commands, "keyword")
 
@@ -277,6 +287,14 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
             self.log.info("Didn't update scratch info %s", self)
 
     # Events {{{
+    async def event_closewindow(self, addr: str) -> None:
+        "close window hook"
+        # removes this address from the extra_addr
+        addr = "0x" + addr
+        for scratch in self.scratches.values():
+            if addr in scratch.extra_addr:
+                scratch.extra_addr.remove(addr)
+
     async def event_monitorremoved(self, monitor_name: str) -> None:
         "Hides scratchpads on the removed screen"
         for scratch in self.scratches.values():
@@ -625,7 +643,7 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
             position_fixed = await self._fix_position(scratch, monitor)
 
         clients = await self.hyprctlJSON("clients")
-        await self._handle_multiwindow(scratch, clients)
+        await self._handle_multiwindow(scratch, clients)  # not very useful but cheap
         # move
         move_commands = [
             f"moveworkspacetomonitor special:scratch_{scratch.uid} {monitor['name']}",
@@ -750,6 +768,9 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
             await notify_error(f"Scratchpad '{uid}' is not visible, will not hide.")
             self.log.warning("%s is already hidden", uid)
             return
+        # collects window which have been created by the app
+        if self.cast_bool(scratch.conf.get("multi"), True):
+            await self._handle_multiwindow(scratch, await self.hyprctlJSON("clients"))
         scratch.visible = False
         scratch.meta.should_hide = False
         self.log.info("Hiding %s", uid)
